# Python Library for BitShares

![](https://img.shields.io/pypi/v/bitshares.svg?style=for-the-badge)
![](https://img.shields.io/github/release/xeroc/python-bitshares.svg?style=for-the-badge)
![](https://img.shields.io/github/downloads/xeroc/python-bitshares/total.svg?style=for-the-badge)
![](https://img.shields.io/pypi/pyversions/bitshares.svg?style=for-the-badge)
![](https://img.shields.io/pypi/l/bitshares.svg?style=for-the-badge)

**Stable**

[![docs master](https://readthedocs.org/projects/python-bitshares/badge/?version=latest)](http://python-bitshares.readthedocs.io/en/latest/)
[![Travis master](https://travis-ci.org/xeroc/python-bitshares.png?branch=master)](https://travis-ci.org/xeroc/python-bitshares)
[![codecov](https://codecov.io/gh/xeroc/python-bitshares/branch/master/graph/badge.svg)](https://codecov.io/gh/xeroc/python-bitshares)

**Develop**

[![docs develop](https://readthedocs.org/projects/python-bitshares/badge/?version=develop)](http://python-bitshares.readthedocs.io/en/develop/)
[![Travis develop](https://travis-ci.org/xeroc/python-bitshares.png?branch=develop)](https://travis-ci.org/xeroc/python-bitshares)
[![codecov develop](https://codecov.io/gh/xeroc/python-bitshares/branch/develop/graph/badge.svg)](https://codecov.io/gh/xeroc/python-bitshares)

---

## Documentation

Visit the [pybitshares website](http://docs.pybitshares.com/en/latest/) for in depth documentation on this Python library.

## Installation

### Install with pip3:
```
$ sudo apt-get install libffi-dev libssl-dev python-dev python3-dev python3-pip
$ pip3 install bitshares
```

### Manual installation:
```
$ git clone https://github.com/xeroc/python-bitshares/
$ cd python-bitshares
$ python3 setup.py install --user
```

### Upgrade
```
$ pip3 install --user --upgrade
```
